import { IPage } from "./page.model";
import { IEventEmitter } from "./event-emitter.model";
import { ElementAttributes } from "../element-attributes";
import { IElementAttributes, IElementClasses } from "./list.model";
import { IElementStyles } from './style.model';
import { PageCustomNodeSchema, PageElementNodeSchema, PageNodeSchema, PageTextNodeSchema } from "./element-schema.model";
export interface PageNodeAttribute {
    name: string;
    value: string;
}
export type PageNode = IPageBaseNode | IPageElementNode | IPageTextNode | IPageCustomNode;
export declare enum NodeType {
    text = 0,
    element = 1,
    custom = 2
}
export interface IPageBaseNode extends IEventEmitter {
    nativeElement: Node | Element;
    hostElement: Node | Element;
    attributes: IElementAttributes;
    nodeType: NodeType;
    key: string;
    children?: IPageBaseNode[];
    schema: PageNodeSchema;
    page: IPage;
    parentElement?: IPageElementNode | undefined;
    findElement(predicate: (el: IPageBaseNode) => boolean): IPageBaseNode | undefined;
    destroy(): void;
    getSchema(): PageNodeSchema;
    changeElementIndex(newIndex: number): void;
}
export interface IPageElementNode extends IPageBaseNode {
    parentElement?: IPageElementNode;
    nativeElement: HTMLElement;
    classList: IElementClasses;
    styles: IElementStyles;
    attributes: IElementAttributes;
    children: PageNode[];
    getSchema(): PageElementNodeSchema;
    findElement(predicate: (el: PageNode) => boolean): PageNode | undefined;
    insertChild(schema: PageNodeSchema): PageNode;
    insertHTMLFragment(fragment: string): PageNode[];
    changeElementIndex(newIndex: number): void;
    removeChild(child: IPageBaseNode): void;
}
export interface IPageTextNode extends IPageBaseNode {
    parentElement?: IPageElementNode;
    nativeElement: Text;
    attributes: ElementAttributes;
    wrapper?: HTMLElement;
    schema: PageTextNodeSchema;
    getSchema(): PageTextNodeSchema;
    wrap(wrapperTag: string): HTMLElement;
    getValue(): string;
}
export interface IPageCustomNode extends IPageBaseNode {
    getSchema(): PageCustomNodeSchema;
    updateSchema(schema: PageCustomNodeSchema): void;
}
